@@ -39,6 +39,7 @@ escaped_for_md <- paste0("\\", c(
   "acronym", "code", "command", "CRANpkg", "deqn", "doi", "dontrun",
   "dontshow", "donttest", "email", "env", "eqn", "figure", "file",
   "if", "ifelse", "kbd", "link", "linkS4class", "method",
+  "mjeqn", "mjdeqn", "mjseqn", "mjsdeqn", "mjteqn", "mjtdeqn",
   "newcommand", "option", "out", "packageAuthor",
   "packageDescription", "packageDESCRIPTION", "packageIndices",
   "packageMaintainer", "packageTitle", "pkg", "PR", "preformatted",
@@ -84,14 +85,9 @@ find_fragile_rd_tags <- function(text, fragile) {
   ftags <- tags[ tags$tag %in% fragile, ]
 
   ## Remove embedded ones
-  keep <- vapply(
-    seq_len(nrow(ftags)),
-    function(i) {
-      sum(ftags$start <= ftags$start[i] &
-            ftags$argend >= ftags$argend[i]) == 1
-    },
-    TRUE
-  )
+  keep <- map_lgl(seq_len(nrow(ftags)), function(i) {
+    sum(ftags$start <= ftags$start[i] & ftags$argend >= ftags$argend[i]) == 1
+  })
 
   ftags <- ftags[keep, ]
 
@@ -119,14 +115,10 @@ find_all_rd_tags <- function(text) {
 
   ## Find the end of the argument list for each tag. Note that
   ## tags might be embedded into the arguments of other tags.
-  tags$argend <- vapply(
-    seq_len(nrow(tags)),
-    function(i) {
+  tags$argend <- map_int(seq_len(nrow(tags)), function(i) {
       tag_plus <- str_sub(text, tags$end[i], text_len)
       findEndOfTag(tag_plus, is_code = FALSE) + tags$end[i]
-    },
-    1L
-  )
+  })
 
   tags
 }
@@ -194,7 +186,7 @@ str_sub_same <- function(str, repl, id) {
   repl <- repl[ order(repl$start), ]
 
   if (is.unsorted(repl$end) || is.unsorted(repl$argend)) {
-    stop("Replacement intervals must not overlap")
+    cli::cli_abort("Replacement intervals must not overlap", .internal = TRUE)
   }
 
   for (i in seq_len(nrow(repl))) {
@@ -229,15 +221,32 @@ make_random_string <- function(length = 32) {
   )
 }
 
-#' Escape \\% and \\$ and \\_ once more, because commonmark
-#' removes the escaping. We do this everywhere currently.
+#' Check markdown escaping
+#'
+#' This is a regression test for Markdown escaping.
+#'
+#' @details
+#' Each of the following bullets should look the same when rendered:
+#'
+#' * Double escapes: \\, \\%, \\$, \\_
+#' * Backticks: `\`, `\%`, `\$`, `\_`
+#' * `\verb{}`: \verb{\\}, \verb{\\%}, \verb{\$}, \verb{\_}
+#'
+#' \[ this isn't a link \]
+#' \\[ neither is this \\]
 #'
 #' @param text Input text.
 #' @return Double-escaped text.
-
+#' @keywords internal
+#' @examples
+#' "%" # percent
+#' "\"" # double quote
+#' '\'' # single quote
 double_escape_md <- function(text) {
-  text <- gsub("\\%", "\\\\%", text, fixed = TRUE)
-  text <- gsub("\\_", "\\\\_", text, fixed = TRUE)
-  text <- gsub("\\$", "\\\\$", text, fixed = TRUE)
+  text <- gsub("\\", "\\\\", text, fixed = TRUE)
+
+  # De-dup escaping used to avoid [] creating a link
+  text <- gsub("\\\\[", "\\[", text, fixed = TRUE)
+  text <- gsub("\\\\]", "\\]", text, fixed = TRUE)
   text
 }
