@@ -108,6 +108,7 @@ topics_process_inherit <- function(topics, env) {
   topics$topo_apply(inherits("examples"), inherit_field, "examples")
   topics$topo_apply(inherits("author"), inherit_field, "author")
   topics$topo_apply(inherits("source"), inherit_field, "source")
+  topics$topo_apply(inherits("note"), inherit_field, "note")
 
   # First inherit individual sections, then all sections.
   topics$topo_apply(function(x) x$inherits_section_from(), inherit_section)
@@ -132,32 +133,53 @@ inherit_params <- function(topic, topics) {
   needed <- topic$get_value("formals")
   missing <- setdiff(needed, documented)
   if (length(missing) == 0) {
-    warn(paste0(
-      "Topic '", topic$get_name(), "': ",
-      "no parameters to inherit with @inheritParams"
-    ))
+    cli::cli_warn(
+      c(
+        "@inheritParams failed in topic {.str {topic$get_name()}}.",
+        x = "All parameters are already documented; none remain to be inherited."
+      ),
+      call = NULL
+    )
     return()
   }
 
+  # Work through inherited params seeing if any match the parameters
+  # we're missing
   for (inheritor in inheritors) {
-    inherited <- find_params(inheritor, topics)
+    inherited_params <- find_params(inheritor, topics, source = topic$get_name())
 
-    matches <- map_chr(missing, match_param, names(inherited))
-    new_match <- !is.na(matches)
-
-    if (!any(new_match)) {
-      # Can't warn here because @inherit inherits parameters
-      next
+    for (param in inherited_params) {
+      match <- match_param(param$name, missing)
+      if (!is.null(match)) {
+        param_val <- setNames(param$value, paste(match, collapse = ","))
+        topic$add(rd_section("param", param_val))
+        missing <- setdiff(missing, match)
+      }
     }
-
-    topic$add(
-      rd_section(
-        "param",
-        setNames(inherited[matches[new_match]], missing[new_match])
-      )
-    )
-    missing <- missing[!new_match]
+    if (length(missing) == 0) break
   }
+
+}
+
+# Ignore . prefix since it's sometimes necessary to add because a
+# function uses ...
+
+# Match parameters ignoring dots
+match_param <- function(from, to) {
+  flip_dot <- function(x) {
+    has_dot <- grepl("^\\.", x)
+    ifelse(has_dot, gsub("^\\.", "", x), paste0(".", x))
+  }
+
+  to_std <- c(to, flip_dot(to))
+  if (!all(from %in% to_std)) {
+    return(NULL)
+  }
+
+  union(
+    setdiff(to[match(from, to)], NA),
+    setdiff(to[match(from, flip_dot(to))], NA)
+  )
 }
 
 inherit_dot_params <- function(topic, topics, env) {
@@ -167,14 +189,17 @@ inherit_dot_params <- function(topic, topics, env) {
 
   # Need to find formals for each source
   funs <- lapply(inheritors$source, function(x) eval(parse(text = x), envir = env))
-  args <- map2(funs, inheritors$args, select_args_text)
+  args <- map2(funs, inheritors$args, select_args_text, topic = topic)
 
   # Then pull out the ones we need
   docs <- lapply(inheritors$source, find_params, topics = topics)
   arg_matches <- function(args, docs) {
-    doc_args <- str_split(names(docs), ", ?")
-    match <- map_lgl(doc_args, function(x) x %in% args)
-    docs[match]
+    match <- map_lgl(docs, function(x) all(x$name %in% args))
+    matched <- docs[match]
+    setNames(
+      lapply(matched, "[[", "value"),
+      map_chr(matched, function(x) paste(x$name, collapse = ","))
+    )
   }
   docs_selected <- unlist(map2(args, docs, arg_matches))
 
@@ -186,7 +211,7 @@ inherit_dot_params <- function(topic, topics, env) {
   # Build the Rd
   # (1) Link to function(s) that was inherited from
   src <- inheritors$source
-  dest <- ifelse(has_colons(src), gsub("::", ":", src), paste0("=", src))
+  dest <- map_chr(src, resolve_qualified_link)
   from <- paste0("\\code{\\link[", dest, "]{", src, "}}", collapse = ", ")
 
   # (2) Show each inherited argument
@@ -218,8 +243,8 @@ get_documented_params <- function(topic, only_first = FALSE) {
   documented
 }
 
-find_params <- function(name, topics) {
-  topic <- get_rd(name, topics)
+find_params <- function(name, topics, source) {
+  topic <- get_rd(name, topics, source = source)
   if (is.null(topic)) {
     return()
   }
@@ -231,30 +256,28 @@ find_params <- function(name, topics) {
   param_names <- str_trim(names(params))
   param_names[param_names == "\\dots"] <- "..."
 
-  # Split up compound names on , (swallowing spaces) duplicating their contents
-  individual_names <- strsplit(param_names, ",\\s*")
-  reps <- map_int(individual_names, length)
-
-  setNames(rep.int(params, reps), unlist(individual_names))
+  Map(list,
+    name = strsplit(param_names, ",\\s*"),
+    value = unlist(params)
+  )
 }
 
-topic_params <- function(x) UseMethod("topic_params")
-topic_params.Rd <- function(x) {
-  arguments <- get_tags(x, "\\arguments")
-  if (length(arguments) != 1) {
-    return(list())
+topic_params <- function(x) {
+  if (inherits(x, "Rd")) {
+    arguments <- get_tags(x, "\\arguments")
+    if (length(arguments) != 1) {
+      return(list())
+    }
+    items <- get_tags(arguments[[1]], "\\item")
+
+    values <- map_chr(items, function(y) rd2text(y[[2]], attr(x, "package")))
+    params <- map_chr(items, function(y) rd2text(y[[1]], attr(x, "package")))
+
+    setNames(values, params)
+  } else {
+    x$get_value("param")
   }
-  items <- get_tags(arguments[[1]], "\\item")
-
-  values <- map_chr(items, function(x) rd2text(x[[2]]))
-  params <- map_chr(items, function(x) rd2text(x[[1]]))
-
-  setNames(values, params)
 }
-topic_params.RoxyTopic <- function(x) {
-  x$get_value("param")
-}
-
 
 # Inherit sections --------------------------------------------------------
 
@@ -293,10 +316,14 @@ inherit_section <- function(topic, topics) {
     selected <- new_section$title %in% titles[[i]]
 
     if (sum(selected) != 1) {
-      warning(
-        "Can't find section '", titles[[i]], "' in ?",
-        sources[[i]], call. = FALSE
+      cli::cli_warn(
+        c(
+          "@inheritSection failed in topic {.str {topic$get_name()}}.",
+          x = "Can't find section {.str {titles[[i]]}} in topic {sources[[i]]}."
+        ),
+        call = NULL
       )
+      return()
     }
 
     topic$add(
@@ -309,10 +336,10 @@ find_sections <- function(topic) {
   if (inherits(topic, "Rd")) {
     tag <- get_tags(topic, "\\section")
 
-    titles <- map_chr(map(tag, 1), rd2text)
-    contents <- map_chr(map(tag, 2), rd2text)
+    titles <- map_chr(map(tag, 1), rd2text, package = attr(topic, "package"))
+    contents <- map_chr(map(tag, 2), rd2text, package = attr(topic, "package"))
 
-    list(title = titles, contents = contents)
+    list(title = titles, content = contents)
   } else {
     topic$get_value("section")
   }
@@ -328,7 +355,7 @@ inherit_field <- function(topic, topics, rd_name, roxy_name = rd_name) {
 
   # Otherwise, try each try function listed in inherits
   for (inherit_from in topic$inherits_from(roxy_name)) {
-    inherit_topic <- get_rd(inherit_from, topics)
+    inherit_topic <- get_rd(inherit_from, topics, source = topic$get_name())
     if (is.null(inherit_topic)) {
       next
     }
@@ -351,66 +378,96 @@ find_field <- function(topic, field_name) {
     value <- tag[[1]]
     attr(value, "Rd_tag") <- NULL
 
-    str_trim(rd2text(value))
+    str_trim(rd2text(value, attr(topic, "package")))
   } else {
     topic$get_value(field_name)
   }
 }
 
+rd2text <- function(x, package) {
+  x <- tweak_links(x, package)
+  chr <- as_character_rd(structure(x, class = "Rd"), deparse = TRUE)
+  paste(chr, collapse = "")
+}
+
+# Convert relative to absolute links
+tweak_links <- function(x, package) {
+  tag <- attr(x, "Rd_tag")
+
+  if (is.list(x)) {
+    if (!is.null(tag) && tag == "\\link") {
+      opt <- attr(x, "Rd_option")
+      if (is.null(opt)) {
+        if (has_topic(x[[1]], package)) {
+          attr(x, "Rd_option") <- structure(package, Rd_tag = "TEXT")
+        }
+      } else if (is_string(opt) && substr(opt, 1, 1) == "=") {
+        topic <- substr(opt, 2, nchar(opt))
+
+        if (has_topic(topic, package)) {
+          attr(x, "Rd_option") <- structure(paste0(package, ":", topic), Rd_tag = "TEXT")
+        }
+      }
+    } else if (length(x) > 0) {
+      x[] <- map(x, tweak_links, package = package)
+    }
+  }
+
+  x
+}
+
+
 # Find info in Rd or topic ------------------------------------------------
 
-get_rd <- function(name, topics) {
+get_rd <- function(name, topics, source) {
   if (has_colons(name)) {
     # External package
     parsed <- parse_expr(name)
     pkg <- as.character(parsed[[2]])
     fun <- as.character(parsed[[3]])
 
-    tweak_links(get_rd_from_help(pkg, fun), package = pkg)
+    get_rd_from_help(pkg, fun, source)
   } else {
     # Current package
     rd_name <- topics$find_filename(name)
     if (identical(rd_name, NA_character_)) {
-      warn(paste0("Can't find help topic '", name, "' in current package"))
+      cli::cli_warn(
+        c(
+          "@inherits failed in topic {.str {source}}.",
+          x = "Can't find topic {.str {name}}."
+        ),
+        call = NULL
+      )
     }
     topics$get(rd_name)
   }
 }
 
-get_rd_from_help <- function(package, alias) {
+get_rd_from_help <- function(package, alias, source) {
   if (!is_installed(package)) {
-    warn(paste0("Can't find package '", package, "'"))
+    cli::cli_warn(
+      c(
+        "@inherits failed in topic {.str {source}}.",
+        x = "Package {package} is not installed."
+      ),
+      call = NULL
+    )
     return()
   }
 
-  help <- eval(expr(help(!!alias, !!package)))
+  help <- utils::help((alias), (package))
   if (length(help) == 0) {
-    warn(paste0("Can't find help topic '", alias, "' in '", package, "' package"))
+    cli::cli_warn(
+      c(
+        "@inherits failed in topic {.str {source}}.",
+        x = "Can't find topic {package}::{alias}."
+      ),
+      call = NULL
+    )
     return()
   }
 
-  internal_f("utils", ".getHelpFile")(help)
+  out <- internal_f("utils", ".getHelpFile")(help)
+  attr(out, "package") <- package
+  out
 }
-
-
-# helpers -----------------------------------------------------------------
-
-# Returns matching parameter name in haystack
-match_param <- function(needle, haystack) {
-  if (needle %in% haystack) {
-    return(needle)
-  }
-
-  if (substr(needle, 1, 1) == ".") {
-    if (needle %in% paste0(".", haystack)) {
-      return(substr(needle, 2, nchar(needle)))
-    }
-  } else {
-    if (paste0(".", needle) %in% haystack) {
-      return(paste0(".", needle))
-    }
-  }
-
-  NA
-}
-
