@@ -33,12 +33,10 @@ roxygenize <- function(package.dir = ".",
   base_path <- normalizePath(package.dir)
   is_first <- roxygen_setup(base_path)
 
-  encoding <- desc::desc_get("Encoding", file = base_path)[[1]]
-  if (!identical(encoding, "UTF-8")) {
-    warning("roxygen2 requires Encoding: UTF-8", call. = FALSE)
-  }
-
   roxy_meta_load(base_path)
+  # Load required packages for method registration
+  packages <- roxy_meta_get("packages")
+  lapply(packages, loadNamespace)
 
   roclets <- roclets %||% roxy_meta_get("roclets")
   # Special case collate: it doesn't need to execute code, and must be run
@@ -53,6 +51,16 @@ roxygenize <- function(package.dir = ".",
 
   roclets <- lapply(roclets, roclet_find)
 
+  if (!is_interactive()) {
+    withr::local_options(warn = 1)
+  }
+
+  # Now load code
+  load_code <- find_load_strategy(load_code)
+  env <- load_code(base_path)
+  roxy_meta_set("env", env)
+  on.exit(roxy_meta_set("env", NULL), add = TRUE)
+
   # Tokenise each file
   blocks <- parse_package(base_path, env = NULL)
 
@@ -65,9 +73,6 @@ roxygenize <- function(package.dir = ".",
     base_path = base_path
   )
 
-  # Now load code
-  load_code <- find_load_strategy(load_code)
-  env <- load_code(base_path)
   blocks <- lapply(blocks, block_set_env, env = env)
 
   results <- lapply(roclets, roclet_process,
@@ -88,27 +93,3 @@ roxygenize <- function(package.dir = ".",
 #' @rdname roxygenize
 #' @export
 roxygenise <- roxygenize
-
-roxygen_setup <- function(base_path) {
-  is_first <- first_time(base_path)
-  if (is_first) {
-    message("First time using roxygen2. Upgrading automatically...")
-  }
-
-  man_path <- file.path(base_path, "man")
-  dir.create(man_path, recursive = TRUE, showWarnings = FALSE)
-  update_roxygen_version(base_path)
-
-  is_first
-}
-
-roxy_warning <- function(..., file = NA, line = NA) {
-  message <- paste0(
-    if (!is.na(file)) paste0("[", file, ":", line, "] "),
-    ...,
-    collapse = " "
-  )
-
-  warning(message, call. = FALSE, immediate. = TRUE)
-  NULL
-}
